isolate_task_queue library
Support for doing something awesome.
More dartdocs go here.
Classes
- FlutterIsolateInstance
- /////////////////////////////////////////////////////////////////////////// One instance for an isolate. Easiest approach: Implement your class without isolate.
- FlutterIsolateInstancePool
- ///////////////////////////////////////////////////////////////////////////
- ParallelTaskQueue
- /////////////////////////////////////////////////////////////////////////// Queue to execute Futures in order.
- SimpleTaskQueue
- /////////////////////////////////////////////////////////////////////////// Queue to execute Futures in order. It awaits each future before executing the next one.
- TaskQueue
- Abstract class for a queue to execute Futures in order.
Typedefs
- CreateInstanceFunction = void Function(Object object)
-
always annotate your entry point with
@pragma('vm:entry-point') -
EntryPoint<
V, R> = Future< V> Function(R request) -
always annotate your entry point with
@pragma('vm:entry-point') -
StreamEntryPoint<
V, R> = Future< Stream< Function(R request)V> > -
always annotate your entry point with
@pragma('vm:entry-point')